PCB Environment: NavPoint Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
NavPoint Class Reference

`#include <NavPoint.hpp>`

## Public Member Functions
void | setRefPoint (int x, int y, int z)
Point_2 | getRefPoint (const UniformGrid25 *nav) const
Point_25 | getRefPoint25 (const UniformGrid25 *nav) const
uint8_t | getLayer () const
bool | hasEdge (GridDirection d) const
NavPoint * | getEdge (NavGrid &, GridDirection d) const
void | setEdge (GridDirection d, bool mask)
Segment_25 | getSegmentTo (const NavPoint &v, const UniformGrid25 *nav) const
const NavKeepoutCounts & | getKOCounts () const
NavKeepoutCounts & | getKOCounts ()
void | resetKO ()
bool | canRoute () const
bool | canPlaceVia () const
bool | canPlaceViaEver () const
bool | canAddVia (const NavPoint &to) const
bool | canAddViaEver (const NavPoint &to) const
bool | insidePin () const
bool | hasFlags (uint16_t mask) const
uint16_t | getFlags () const
void | setFlags (uint16_t mask)
void | clearFlags (uint16_t mask)
void | saveFlags ()
void | restoreFlags ()
void | write (const NavRasterizeParams &)
void | copyFrom (const NavPoint &)
float | getCost (uint term) const
void | setCost (uint term, float cost)
float | getScore () const
void | setScore (float score)
NavPoint * | getBackEdge (NavGrid &nav) const
GridDirection | getBackDirection () const
void | setBackDirection (GridDirection d)
AStarVisitStatus & | getVisits ()
const AStarVisitStatus & | getVisits () const
uint16_t | getWriteSeq () const
void | setWriteSeq (uint16_t v)
std::string | str (const NavGrid *) const

## Detailed Description

This class represents a cell in the 3D grid representation of the board. Grid cells will be 1x1 length units as per PCBoard(UnitLengthInNanoMeters). Each cell has 8 horizontal + 2 vertical edges (indexed by GridDirection), pointing to its neighbours (or null). NavPoint also contains temporary data required by A*.

The documentation for this class was generated from the following files:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavPoint.hpp
- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavGrid.hpp